<?php

// get the current URL
function nb_curr_url() {
	$pageURL = 'http';

	if ((isset($_SERVER["HTTPS"]) && $_SERVER["HTTPS"] == "on") || (function_exists('is_ssl') && is_ssl())) {$pageURL .= "s";}
	$pageURL .= "://" . $_SERVER['HTTP_HOST'].$_SERVER["REQUEST_URI"];

	return $pageURL;
}


// get file extension from a filename
function nb_stringToExt($string) {
	$pos = strrpos($string, '.');
	$ext = strtolower(substr($string,$pos));
	return $ext;
}


// get filename without extension
function nb_stringToFilename($string, $raw_name = false) {
	$pos = strrpos($string, '.');
	$name = substr($string,0 ,$pos);
	if(!$raw_name) {$name = ucwords(str_replace('_', ' ', $name));}
	return $name;
}


// string to url format // NEW FROM v1.11 for non-latin characters
function nb_stringToUrl($string){

	// if already exist at least an option, use the default encoding
	if(!get_option('mg_non_latin_char')) {
		$trans = array("à" => "a", "è" => "e", "é" => "e", "ò" => "o", "ì" => "i", "ù" => "u");
		$string = trim(strtr($string, $trans));
		$string = preg_replace('/[^a-zA-Z0-9-.]/', '_', $string);
		$string = preg_replace('/-+/', "_", $string);
	}

	else {$string = trim(urlencode($string));}

	return $string;
}


// normalize a url string
function nb_urlToName($string) {
	$string = ucwords(str_replace('_', ' ', $string));
	return $string;
}


// sanitize input field values
function nb_sanitize_input($val) {
	global $wp_version;

	// not sanitize quotes  in WP 4.3 and newer
	if ($wp_version >= 4.3) {
		return trim(esc_attr($val));	
	}
	else {
		return trim(
			str_replace(array('\'', '"', '<', '>', '&'), array('&apos;', '&quot;', '&lt;', '&gt;', '&amp;'), (string)$val)
		);	
	}
}


// convert HEX to RGB
function nb_hex2rgb($hex) {
   	// if is RGB or transparent - return it
   	$pattern = '/^#[a-f0-9]{6}$/i';
	if(empty($hex) || $hex == 'transparent' || !preg_match($pattern, $hex)) {return $hex;}

	$hex = str_replace("#", "", $hex);
   	if(strlen($hex) == 3) {
		$r = hexdec(substr($hex,0,1).substr($hex,0,1));
		$g = hexdec(substr($hex,1,1).substr($hex,1,1));
		$b = hexdec(substr($hex,2,1).substr($hex,2,1));
	} else {
		$r = hexdec(substr($hex,0,2));
		$g = hexdec(substr($hex,2,2));
		$b = hexdec(substr($hex,4,2));
	}
	$rgb = array($r, $g, $b);

	return 'rgb('. implode(",", $rgb) .')'; // returns the rgb values separated by commas
}


// convert RGB to HEX
function nb_rgb2hex($rgb) {
   	// if is hex or transparent - return it
   	$pattern = '/^#[a-f0-9]{6}$/i';
	if(empty($rgb) || $rgb == 'transparent' || preg_match($pattern, $rgb)) {return $rgb;}

  	$rgb = explode(',', str_replace(array('rgb(', ')'), '', $rgb));

	$hex = "#";
	$hex .= str_pad(dechex( trim($rgb[0]) ), 2, "0", STR_PAD_LEFT);
	$hex .= str_pad(dechex( trim($rgb[1]) ), 2, "0", STR_PAD_LEFT);
	$hex .= str_pad(dechex( trim($rgb[2]) ), 2, "0", STR_PAD_LEFT);

	return $hex;
}


// hex color to RGBA
function nb_hex2rgba($hex, $alpha) {
	$rgba = str_replace(array('rgb', ')'), array('rgba', ', '.$alpha.')'), nb_hex2rgb($hex));
	return $rgba;
}


// recalculate serialized elements length - fix for DB get issues
function nb_fix_serialization($string) {
	//return preg_replace('!s:(\d+):"(.*?)";!e', "'s:'.strlen('$2').':\"$2\";'", $string); // global chars recalculation
	return str_replace(array('&amp;'), array('&'), $string);
}


// get public custom post types and taxonomies
function nb_get_cpt_with_tax() {
	$cpt = get_post_types(array('public' => true, '_builtin' => false), 'objects');
	$usable = array();

	foreach($cpt as $pt) {
		$tax = get_object_taxonomies($pt->name, 'objects');

		// add only if has a taxonomy
		if(is_array($tax) && !empty($tax)) {
			$tax_array = array();

			foreach($tax as $slug => $data) {
				$tax_array[$slug] = $data->labels->name;
			}

			$usable[ $pt->name ] = array(
				'name' => $pt->labels->name,
				'tax' => $tax_array
			);
		}
	}
	return $usable;
}


// given CPT+taxonomy slugs, returns human names
function nb_cptTax_to_cpt_name($cpt_tax) {
	$arr = explode('|||', $cpt_tax);

	$cpt = get_post_type_object($arr[0]);
    if(!is_object($cpt)) {
        return false;    
    }
    
	$cpt = $cpt->labels->name;

	$tax = get_taxonomy($arr[1]);
	$tax = $tax->labels->name;

	return $cpt .' - '. $tax;
}


// know if woocommerce is active
function nb_woocomm_active() {
	return (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')) )) ? true : false;
}



/////////////////////////////



// add custom CSS to core plugin file
function nb_create_custom_theme() {
	global $wp_filesystem;
		
	if(empty($wp_filesystem)) {
		require_once (ABSPATH .'/wp-admin/includes/file.php');
		WP_Filesystem();
	}
	
	ob_start();
	require_once(NB_DIR.'/custom_theme_css.php');
	
	$css = ob_get_clean();
	if(trim($css) != '') {
		if(!$wp_filesystem->put_contents(NB_DIR .'/js/sb/themes/wpdt.css', $css)) {
			$error = true;
		}
		else {
			update_option('nb_dynamic_scripts_id', md5($css));	
		}
	}
	else {
		if(file_exists(NB_DIR .'/js/sb/themes/wpdt.css'))	{
			wp_delete_file(NB_DIR .'/js/sb/themes/wpdt.css');
		}
	}
	
	return (isset($error)) ? false : true;
}



// turn jQuery.serializeArray() ajax data into php array
function nb_serArr_to_php($values) {
	$final_arr = array();

	foreach($values as $val) {
		if(strpos($val->name, '[]') === false) {
			$index = $val->name;
			$val = $val->value;
		}
		else {
			$index = str_replace('[]', '', $val->name);
			$val = array( nb_sanitize_input($val->value) );
		}

		if(isset($final_arr[$index])) {
			$final_arr[$index][] = $val[0];
		} else {
			$final_arr[$index] = $val;
		}
	}

	return $final_arr;
}



// php to javascript value
function nb_php_to_js_datatype($index, $val) {
	
	if(is_array($val) || $index == 'hide_elements') { // "hide elements"
		$js_val = (empty($val)) ? '[]' : '["'. implode('","', $val) .'"]';
	}
    elseif($index == 'match_words') { // "match_words" source option
		$js_val = (empty($val)) ? '[]' : '["'. implode('","', explode(',', $val)) .'"]';
	}
    
	else if(nb_is_bool_opt($index)) {
		$js_val = ($val) ? 'true' : 'false';
	}
	else if(filter_var($val, FILTER_VALIDATE_INT)) {
		$js_val = $val;
	}
	else {
		$js_val = "'". str_replace("'", "\'", $val) ."'";

		// nav btn position
		if($index == 'nav_arrows' && $val == 'false') {$js_val = $val;}
	}

	return $js_val;
}



// check if is a boolean field
function nb_is_bool_opt($opt_id) {
	$data = nb_types_opt($opt_id);
	
    if(is_array($data)) {
       return ($data['type'] == 'bool') ? true : false;
    } else {
       return false;
    }
}



// remote sources - subject option index
function nb_src_opt_index($type) {
	switch($type) {
		case 'rss' :
		case 'pinterest' :
		case 'tumblr' :
		case 'instagram' :
			$index = 'url';
			break;

		case 'facebook' :
		case 'google' :
		case 'twitter' :
		case 'youtube' :
		default :
			$index = 'id';
			break;
	}

	return $index;
}



/////////////////////////////////////////////////////



// main styles
function nb_main_styles($style = '') {
	$styles = array(
		'minimal' => array(
			'preview' => 'minimal.jpg',
			'css' => 'minimal.css'
		),
		'light' => array(
			'preview' => 'light.jpg',
			'css' => 'light.css'
		),
		'dark' => array(
			'preview' => 'dark.jpg',
			'css' => 'dark.css'
		)
	);

	if($style == '') {return $styles;}
	else {return $styles[$style];}
}


// news sources
function nb_news_sources($src = '') {
	$sources = array(
		'wp_cat' 		=> __('Wordpress category', 'nb_ml'),
		'qn_cat' 		=> __('Quick News category', 'nb_ml'),
		'rss' 			=> __('RSS Feed', 'nb_ml'),
		'instagram'		=> 'Instagram',
		'twitter' 		=> 'Twitter',
		'youtube' 		=> 'Youtube',
		'pinterest' 	=> 'Pinterest',
		'tumblr' 		=> 'Tumblr',
	);

	// woocommerce integration
	if(nb_woocomm_active() || $src != '') { // exception if is viewing an already existing source
		$sources['woo_cat'] = __('WooCommerce category', 'nb_ml');
	}

	// add custom post type sources
	$cpt = get_option('nb_integrate_cpt');
	if(!empty($cpt)) {
		foreach($cpt as $pt) {
            $name = nb_cptTax_to_cpt_name($pt);
            
            if(!$name) {
                continue;    
            }
            
			$sources[$pt] = $name;
		}
	}

	return ($src == '') ? $sources : $sources[$src];
}



// navigation arrows positions
function nb_nav_arr_pos($pos = '') {
	$positions = array(
		'false' 	=> __("hidden", 'nb_ml'),
		'side' 		=> __("on sides", 'nb_ml'),
		'top_l' 	=> __("top-left", 'nb_ml'),
		'top_c' 	=> __("top-center", 'nb_ml'),
		'top_r' 	=> __("top-right", 'nb_ml'),
		'bottom_l' 	=> __("bottom-left", 'nb_ml'),
		'bottom_c' 	=> __("bottom-center", 'nb_ml'),
		'bottom_r' 	=> __("bottom-right", 'nb_ml'),
	);

	if($pos == '') {return $positions;}
	else {return $positions[$pos];}
}



//////////////////////////////////////////////////////////////////////



// news source - builder form block
function nb_src_form_block($data) {
	$vals = array(
		'src_val' 		=> '',
		'author' 		=> '',
		'hide_elements' => '',
		'link_target' 	=> '',
		'exp_img_pos' 	=> '',
		'exp_img_w' 	=> '',
		'exp_img_h' 	=> 250,
		'self_s_link'	=> '',
		'strip_tags' 	=> '',
		'remove_tags' 	=> '',
        'match_words'=> '',
	);

	// override defaults
	foreach($data as $i => $v) {
		$vals[$i] = $v;
	}


	// source value
	if($data['src_type'] == 'wp_cat') {
		$src_val = '
		<label>'. __('Posts category', 'nb_ml') .'</label>
		<select name="src_val" class="nb_lc_select" data-placeholder="'. esc_attr__('Select a category', 'nb_ml') .'">
			<option value="">'. esc_html__('All', 'nb_ml') .'</option>';

			foreach( get_categories() as $cat ) {
				($cat->term_id == $vals['src_val']) ? $sel = 'selected="selected"' : $sel = '';
				$src_val .= '<option value="'.$cat->term_id.'" '.$sel.'>'. esc_html($cat->name) .'</option>';
			}

		$src_val .= '</select>';
	}
	else if ($data['src_type'] == 'qn_cat') {
		$src_val = '
		<label>'. __('News category', 'nb_ml') .'</label>
		<select name="src_val" class="nb_lc_select" data-placeholder="'. esc_attr__('Select a category', 'nb_ml') .'">
			<option value="">'. esc_html__('All', 'nb_ml') .'</option>';

			$cats = get_terms('nb_news_cat', 'orderby=name&hide_empty=0');
			foreach($cats as $cat ) {
				$sel = ($cat->term_id == $vals['src_val']) ? 'selected="selected"' : '';
				$src_val .= '<option value="'. $cat->term_id .'" '.$sel.'>'. esc_html($cat->name) .'</option>';
			}

		$src_val .= '</select>';
	}
	else if ($data['src_type'] == 'woo_cat') {
		$src_val = '
		<label>'. __('Products category', 'nb_ml') .'</label>
		<select name="src_val" class="nb_lc_select" data-placeholder="'. __('Select a category', 'nb_ml') .'">
			<option value="">'. __('All', 'nb_ml') .'</option>';

			if(nb_woocomm_active()) {
				$cats = get_terms('product_cat', 'orderby=name&hide_empty=0');
				foreach($cats as $cat ) {
					$sel = ($cat->term_id == $vals['src_val']) ? 'selected="selected"' : '';
					$src_val .= '<option value="'.$cat->term_id.'" '.$sel.'>'. esc_html($cat->name) .'</option>';
				}
			}

		$src_val .= '</select>';
	}
	else if(strpos($data['src_type'], '|||') !== false) { // custom post type + taxonomy
		$arr = explode('|||', $data['src_type']);

		$src_val = '
		<label>'. nb_cptTax_to_cpt_name($data['src_type']) .'</label>
		<select name="src_val" class="nb_lc_select" data-placeholder="'. esc_attr__('Select a term', 'nb_ml') .'">
			<option value="">'. esc_html__('All', 'nb_ml') .'</option>';

			$cats = get_terms($arr[1], 'orderby=name&hide_empty=0');
			foreach($cats as $cat ) {
				$sel =  ($cat->term_id == $vals['src_val']) ? 'selected="selected"' : '';
				$src_val .= '<option value="'. $cat->term_id .'" '.$sel.'>'. $cat->name .'</option>';
			}

		$src_val .= '</select>';
	}
	else {
        $label = '';
        
		// source helper
        switch ($data['src_type']) {
            case 'rss' 		    : $label = __("RSS feed URL", 'nb_ml'); break;
            case 'instagram'	: $label = __("Profile URL", 'nb_ml'); break;
            case 'twitter' 	    : $label = __('Profile ID (without "@")', 'nb_ml'); break;
            case 'youtube' 	    : $label = __('Profile/channel ID or Playlist ID (contained in URL)', 'nb_ml'); break;
            case 'pinterest' 	: $label = __("User's board URL", 'nb_ml'); break;
            case 'tumblr' 	    : $label = __("Tumblr's blog URL", 'nb_ml'); break;
        }

		$src_val = '
		<label>'. $label .'</label>
		<input name="src_val" type="text" value="'. esc_attr($vals['src_val']) .'" />';
	}
	
	$code = '
	<div class="nb_full_field">'. $src_val .'</div>
	<input name="src_type" type="hidden" value="'.$data['src_type'].'" />';

	$common_fields = array('news_offset', 'author', 'src_hide_elements', 'link_target', 'exp_img_pos', 'exp_img_w', 'exp_img_h', 'self_s_link', 'strip_tags', 'remove_tags');
	
    // "match words" for non-inline sources
    if(in_array($data['src_type'], array('rss', 'instagram', 'twitter', 'youtube', 'pinterest', 'soundcloud', 'tumblr'))) {
        $common_fields[] = 'match_words';    
    }
    
	// playlist switch for youtube
	if($data['src_type'] == 'youtube') {
		$common_fields = array('is_youtube_playlist') + $common_fields;
	}
	
	foreach($common_fields as $field) {
		$val = (isset($vals[$field])) ? $vals[$field] : '';
		$code .= nb_fields_builder($field, $val, $data['src_type']);
	}

	return $code;
}



// inline source - nb code
function nb_inline_code($src, $limit, $man_exp_img) {

	// check if woocommerce source and plugin is not active
	if(!nb_woocomm_active() && $src['src_type'] == 'woo_cat') {
        return '';
    }

	/*** query ***/
	if(strpos($src['src_type'], '|||') !== false) {
		$cpt_arr = explode('|||', $src['src_type']);
		$pt = $cpt_arr[0];
	}
	else {
		switch($src['src_type']) {
			case 'qn_cat'	: $pt = 'nb_news'; break;
			case 'woo_cat'	: $pt = 'product'; break;
			default			: $pt = 'post'; break;
		}
	}

	$args = array(
		'numberposts' 	=> (int)$limit,
		'post_type' 	=> $pt,
		'offset'		=> (isset($src['news_offset'])) ? (int)$src['news_offset'] : 0
	);

	if(!empty($src['src_val'])) {
		if($src['src_type'] == 'wp_cat') {
			$args['category__in'] = array($src['src_val']);
		}
		elseif($src['src_type'] == 'qn_cat') {
			$args['tax_query'] = array(
				array(
					'taxonomy' => 'nb_news_cat',
					'field' => 'id',
					'terms' => $src['src_val'],
					'include_children' => true
				)
			);
		}
		elseif($src['src_type'] == 'woo_cat') {
			$args['tax_query'] = array(
				array(
					'taxonomy' => 'product_cat',
					'field' => 'id',
					'terms' => $src['src_val'],
					'include_children' => true
				)
			);
		}
		else { // custom post type + taxonomy
			$args['tax_query'] = array(
				array(
					'taxonomy' => $cpt_arr[1],
					'field' => 'id',
					'terms' => $src['src_val'],
					'include_children' => true
				)
			);
		}

		$args['tax_query']['relation'] = 'OR';
	}

	$query = get_posts($args);
	if(!is_array($query) || count($query) == 0) {return '';}

	/*** code building ***/
	// image size control attributes
	if(get_option('nb_img_check')) {
		$img_chk_attr = 'img_max_w="'.get_option('nb_max_img_w', 800).'" img_max_h="'.get_option('nb_max_img_h', 600).'"';
	} else {
		$img_chk_attr = '';
	}

	// exp image control attributes
	if($man_exp_img) {
		$exp_img_attr = 'exp_img_pos="'.$src['exp_img_pos'].'" exp_img_w="'.$src['exp_img_w'].'" exp_img_h="'.$src['exp_img_h'].'"';
	} else {
		$exp_img_attr = 'exp_img_pos="'.$src['exp_img_pos'].'"';
	}

	// strip/remove tags
	$str_rm_tags = '';
	if(isset($src['strip_tags']) && !empty($src['strip_tags'])) {$str_rm_tags .= 'strip_tags="'. trim($src['strip_tags']) .'"';}
	if(isset($src['remove_tags']) && !empty($src['remove_tags'])) {$str_rm_tags .= ' remove_tags="'. trim($src['remove_tags']) .'"';}

	$code = '<div class="nb_news_wrap nb_displaynone" link_target="'.$src['link_target'].'" '.$img_chk_attr.' '.$exp_img_attr.' '.$str_rm_tags.'>';

	foreach($query as $post) {

		// image
		if(has_post_thumbnail($post->ID)) {
			$img_id = get_post_thumbnail_id($post->ID);
			$img_src = wp_get_attachment_image_src($img_id, 'full');
			$img = '<img src="" lazy-src="'.$img_src[0].'" class="lcnb_main_img" />';
		}
		else {$img = '';}

		// media
		$media = (string)get_post_meta($post->ID, 'nb_media', true);
		if($media) {
			$media = '<div class="lcnb_video" src="'. $media .'"></div>';
		}

		// link
		if($src['src_type'] == 'qn_cat') {
			$link = (trim((string)get_post_meta($post->ID, 'nb_link', true))) ? '<a href="'.(string)get_post_meta($post->ID, 'nb_link', true).'" class="lcnb_inline_link"></a>' : '';
		}
		else {$link = '<a href="'.get_permalink($post->ID).'" class="lcnb_inline_link"></a>';}

		// author
		if(!empty($src['author'])) {
			if(strpos($src['author'], '%WP-AUTHOR%') !== false) {
				$user_data = get_user_by('id', $post->post_author);
				$src['author'] = str_replace('%WP-AUTHOR%', $user_data->user_nicename, $src['author']);
			}
			
			$author = '<span class="lcnb_author">'. str_replace(array('&apos;', '&quot;', '&lt;', '&gt;'), array('\'', '"', '<', '>'), $src['author']) .'</span> ';
		}
		else {$author = '';}

		// excerpt
		if(!empty($post->post_excerpt)) {
			$excerpt = '<blockquote>'. $author . nl2br(trim($post->post_excerpt)) .'</blockquote>';
		}
		else {$excerpt = '';}

		$code .= '
		<article datetime="'.get_post_time('c', true, $post->ID).'">
            <header>'.trim($post->post_title).'</header>
            <section>
				'.$author . do_shortcode(wpautop(trim( $post->post_content) )) .'
			</section>
			'.$excerpt.'
			'.$img.'
			'.$media.'
			'.$link.'
        </article>';
	}

	return $code . '</div>';
}



/////////////////////////////////////////////////////////////////////////



// all types option - global cumulative array
function nb_types_opt($type, $src_type = false) {
	$opts = array(

		// news sources
		'news_offset' => array(
			'type' => 'slider',
			'label' => __("News offset", 'nb_ml'),
			'min_val' 	=> 0,
			'max_val' 	=> 50,
			'step' 		=> 1,
			'value' 	=> '',
			'def' 		=> 0
		),
		'author' => array(
			'type' => 'text',
			'label' => (!in_array($src_type, array('rss', 'instagram', 'twitter', 'youtube', 'pinterest', 'soundcloud', 'tubmlr'))) ? __("Author <small>(supports %WP-AUTHOR%)</small>", 'nb_ml') : __("Author", 'nb_ml'),
			'optional' => true
		),
		'src_hide_elements' => array(
			'type' => 'select',
			'label' => __("Hide news elements", 'nb_ml'),
			'opts' => array(
				'title' => __('title', 'nb_ml'), 
				'link'	=> __('link', 'nb_ml')
			),
			'multiple' => true,
			'optional' => true
		),
		'link_target' => array(
			'type' => 'select',
			'label' => __("Open links", 'nb_ml'),
			'opts' => array(
				'_top'		=> __('in the same page', 'nb_ml'), 
				'_blank' 	=> __('in a new page', 'nb_ml')
			),
		),
		'exp_img_pos' => array(
			'type' => 'select',
			'label' => __("Main image position <small>(expanded mode)</small>", 'nb_ml'),
			'opts' => array(
				'inside' => __('inside news text', 'nb_ml'), 
				'side' => __('on left side', 'nb_ml'), 
				'hidden' => __('hidden', 'nb_ml')
			),
		),
		'exp_img_w' => array(
			'type' => 'select',
			'label' => __("Image's container width <small>(expanded mode)</small>", 'nb_ml'),
			'opts' => array(
				'1_4' => __("one fourth's wrapper width", 'nb_ml'),
				'1_3' => __("one third's wrapper width", 'nb_ml'),
				'1_2' => __('half wrapper width', 'nb_ml'),
				'1_1' => __('fullwidth', 'nb_ml')
			),
			'def' => '1_3'
		),
		'exp_img_h' => array(
			'type' => 'text',
			'label' => __("Image's container height <small>(in pixels or AUTO value - expanded mode)</small>", 'nb_ml'),
			'optional' => true
		),
		'self_s_link' => array(
			'type' => 'bool',
			'label' => __("Set page's URL as sharing link?", 'nb_ml'),
		),
		'strip_tags' => array(
			'type' => 'text',
			'label' => __("Strip HTML tags <small>(JS selectors, comma split)</small>", 'nb_ml'),
			'optional' => true
		),
		'remove_tags' => array(
			'type' => 'text',
			'label' => __("Remove HTML tags <small>(JS selectors, comma split)</small>", 'nb_ml'),
			'optional' => true
		),
        'match_words' => array(
			'type' => 'text',
			'label' => __("Keep posts matching one of these words <small>(words comma split)</small>", 'nb_ml'),
			'optional' => true
		),
		'is_youtube_playlist' => array(
			'type' => 'bool',
			'label' => __("Is it a playlist?", 'nb_ml'),
		),


		/*** initial mode ***/
		'max_news' => array(
			'type' => 'slider',
			'label' => __("News to keep", 'nb_ml'),
			'min_val' 	=> 1,
			'max_val' 	=> 50,
			'step' 		=> 1,
			'value' 	=> '',
			'def' 		=> 6
		),
		'news_per_time' => array(
			'type' => 'slider',
			'label' => __("News displayed per time", 'nb_ml'),
			'min_val' 	=> 1,
			'max_val' 	=> 25,
			'step' 		=> 1,
			'value' 	=> '',
			'def' 		=> 3
		),
		'only_w_images' => array(
			'type' => 'bool',
			'label' => __("Keep only news with images?", 'nb_ml'),
		),
		'height' => array(
			'type' => 'slider',
			'label' => __("Box height", 'nb_ml'),
			'min_val' 	=> 70,
			'max_val' 	=> 2000,
			'step' 		=> 10,
			'value' 	=> 'px',
			'def' 		=> 300
		),
		'layout' => array(
			'type' => 'select',
			'label' => __("Box layout", 'nb_ml'),
			'opts' => array(
				'horizontal' => esc_html__("horizontal", 'nb_ml'),
				'vertical' => esc_html__('vertical', 'nb_ml')
			),
		),
		'boxed_news' => array(
			'type' => 'bool',
			'label' => __("Boxed style?", 'nb_ml'),
		),
		'horiz_img_mode' => array(
			'type' => 'bool',
			'label' => __("Horizontal image mode?", 'nb_ml'),
		),
		'buttons_position' => array(
			'type' => 'select',
			'label' => __("Buttons position", 'nb_ml'),
			'opts' => array(
				'bottom' => __("bottom", 'nb_ml'), 
				'top' => __('top', 'nb_ml'), 
				'side' => __('side (only for vertical and boxed layout)', 'nb_ml')
			),
		),
		'hide_elements' => array(
			'type' => 'select',
			'label' => __("Hide elements", 'nb_ml'),
			'opts' => array(
				'date' => esc_html__("date", 'nb_ml'),
				'title' => esc_html__('title', 'nb_ml'),
				'image' => esc_html__('main image', 'nb_ml'),
				'link' => esc_html__('link', 'nb_ml'),
				'socials' => esc_html__('social share', 'nb_ml'),
				'btn_bar' => esc_html__('buttons bar', 'nb_ml')
			),
			'multiple' => true,
			'optional' => true
		),
		'show_src_logo' => array(
			'type' => 'bool',
			'label' => __("Show news source logo? <small>(only vertical layout)</small>", 'nb_ml'),
		),
		'horiz_img_h' => array(
			'type' => 'slider',
			'label' => __("Image's height <small>(for horizontal layout)</small>", 'nb_ml'),
			'min_val' 	=> 30,
			'max_val' 	=> 500,
			'step' 		=> 10,
			'value' 	=> 'px',
			'def' 		=> 180,
			'optional' 	=> true
		),
		'vert_img_w' => array(
			'type' => 'slider',
			'label' => __("Image's width <small>(for vertical layout)</small>", 'nb_ml'),
			'min_val' 	=> 30,
			'max_val' 	=> 500,
			'step' 		=> 10,
			'value' 	=> 'px',
			'def' 		=> 160,
			'optional' 	=> true
		),
		'title_behavior' => array(
			'type' => 'select',
			'label' => __("News title behavior", 'nb_ml'),
			'opts' => array(
				'expand' 	=> __("expand news", 'nb_ml'), 
				'none' 		=> __('no action', 'nb_ml'), 
				'link' 		=> __('redirect to news link', 'nb_ml')
			),
		),
		'img_behavior' => array(
			'type' => 'select',
			'label' => __("Main image behavior", 'nb_ml'),
			'opts' => array(
				'lightbox' 	=> esc_html__("trigger lightbox", 'nb_ml'), 
				'expand' 	=> esc_html__("expand news", 'nb_ml'), 
				'none' 		=> esc_html__('no action', 'nb_ml'), 
				'link' 		=> esc_html__('redirect to news link', 'nb_ml')
			),
		),
		'date_format' => array(
			'type' => 'text',
			'label' => __('Date format', 'nb_ml') .' (<a class="nb_date_guide" href="#">'. __('show guide', 'nb_ml') .'</a>)',
			'def' => get_option('nb_date_format', 'd mmmm yyyy')
		),
		'elapsed_time' => array(
			'type' => 'bool',
			'label' => __("Use elapsed time?", 'nb_ml'),
		),
		'read_more_btn' => array(
			'type' => 'bool',
			'label' => __('Replace date with "read more" button?', 'nb_ml'),
		),
		'read_more_btn_txt' => array(
			'type' => 'text',
			'label' => __('"Read more"', 'nb_ml').' '. __("button's text", 'nb_ml'),
			'def' => __('Read more', 'nb_ml'),
			'optional' => true
		),
		'lightbox' => array(
			'type' => 'bool',
			'label' => __("Use lightbox?", 'nb_ml'),
		),
		'touchswipe' => array(
			'type' => 'bool',
			'label' => __("use touchSwipe?", 'nb_ml'),
		),


		/*** expanded mode ***/
		'expandable_news' => array(
			'type' => 'bool',
			'label' => __('Expandable news?', 'nb_ml'),
		),
		
		'scroll_exp_elem' => array(
			'type' => 'bool',
			'label' => __('Keep close button and side image visible on scroll?', 'nb_ml'),
		),
		'manage_exp_images' => array(
			'type' => 'bool',
			'label' => __('Manage news images?', 'nb_ml'),
		),


		/*** navigation settings ***/
		'nav_arrows' => array(
			'type' => 'select',
			'label' => __("Navigation arrows position", 'nb_ml'),
			'opts' => nb_nav_arr_pos(),
		),
		'carousel' => array(
			'type' => 'bool',
			'label' => __('Carousel mode?', 'nb_ml'),
		),
		'autoplay' => array(
			'type' => 'bool',
			'label' => __('Autoplay slideshow?', 'nb_ml'),
		),
		'animation_time' => array(
			'type' => 'slider',
			'label' => __("Animation time", 'nb_ml'),
			'min_val' 	=> 0,
			'max_val' 	=> 20000,
			'step' 		=> 100,
			'value' 	=> 'ms',
			'def' 		=> 700,
		),
		'slideshow_time' => array(
			'type' => 'slider',
			'label' => __("Slideshow interval", 'nb_ml'),
			'min_val' 	=> 0,
			'max_val' 	=> 10000,
			'step' 		=> 100,
			'value' 	=> 'ms',
			'def' 		=> 4000,
		),
		'pause_on_hover' => array(
			'type' => 'bool',
			'label' => __('Pause slideshow on hover?', 'nb_ml')
		),
		'slide_all' => array(
			'type' => 'bool',
			'label' => __('Slide all visible elements per time?', 'nb_ml')
		),
		'autop_after_exp' => array(
			'type' => 'bool',
			'label' => __('Resume autoplay after expanded news closing?', 'nb_ml')
		),
	);

	return (isset($opts[$type])) ? $opts[$type] : false;
}



// fields builder
function nb_fields_builder($field, $value = '', $src_type = '') {
	$data = nb_types_opt($field, $src_type);
	$pre_code = ($data['type'] == 'textarea') ? '<div class="nb_full_field nb_f_'.$field.'_wrap">' : '<div class="nb_field nb_f_'.$field.'_wrap">';
	$pre_code .= '<label>'.$data['label'].'</label>';

	$def_val = (isset($data['def'])) ? $data['def'] : '';
	if((empty($value) && $value !== '0') && isset($def_val)) {$value = $def_val;}

	$optional = (isset($data['optional'])) ? 'nb_optional_f' : '';
	$class = str_replace('[]', '', $field);

	switch($data['type']) {
		
		case 'text' :
		default : // text
			$code = '<input type="text" name="'. esc_attr($field) .'" class="nb_f_'. esc_attr($class) .' '.$optional.'" value="'. esc_attr($value) .'" />';
			break;


		case 'color':
			$code = '<input type="text" name="'. esc_attr($field) .'" value="'. esc_attr($value) .'" class="nb_lc_colpick nb_f_'. esc_attr($class) .' '.$optional.'" />';
			break;

		case 'slider':
			$code = '<input type="number" value="'. (int)$value .'" min="'. (float)$data['min_val'] .'" max="'. (float)$data['max_val'] .'" step="'. (float)$data['step'] .'" name="'. esc_attr($field) .'" class="nb_lc_range nb_f_'. esc_attr($class) .' '.$optional.'" data-respect-limits="0" data-unit="'. esc_attr($data['value']) .'" />';
			break;

		case 'select':
			if(isset($data['multiple'])) {
				$multiple = 'multiple="multiple"';
				$mfn = '[]';
			} else {
				$multiple = '';
				$mfn = '';
			}

			$options = '';
			foreach($data['opts'] as $k => $v) {
				if(is_array($value)) {
					$sel = (in_array($k, $value)) ? 'selected="selected"' : '';
				} else {
					$sel = ($value == $k) ? 'selected="selected"' : '';
				}

				$options .= '<option value="'.$k.'" '.$sel.'>'.$v.'</option>';
			}

			$code = '
			<select name="'. esc_attr($field.$mfn) .'" class="nb_lc_select nb_f_'. esc_attr($class) .' '.$optional.'" '.$multiple.' data-placeholder="'. esc_attr__('Select an option', NB_ML) .'">
				'.$options.'
			</select> ';
			break;

		case 'bool':
			$sel = ($value == 1) ? 'checked="checked"' : '';
			$code = '<input type="checkbox" value="1" name="'.$field.'" class="nb_lc_check nb_f_'.$class.'" '.$sel.' />';
			break;

		case 'textarea':
			$code = '<textarea name="'.$field.'" class="nb_autoh_textarea nb_f_'.$field.' '.$optional.'" onkeyup="nb_textAreaAdjust(this)">'.$value.'</textarea>';
			break;

		case 'padding_arr':
			if(!is_array($value)) {$value = array('','','','');}

			$code = '
			<input type="text" value="'.$value[0].'" name="'.$field.'[]" class="lcwp_slider_input nb_f_'.$class.' '.$optional.'" maxlength="2" />
			<input type="text" value="'.$value[1].'" name="'.$field.'[]" class="lcwp_slider_input nb_f_'.$class.' '.$optional.'" maxlength="2" />
			<input type="text" value="'.$value[2].'" name="'.$field.'[]" class="lcwp_slider_input nb_f_'.$class.' '.$optional.'" maxlength="2" />
			<input type="text" value="'.$value[3].'" name="'.$field.'[]" class="lcwp_slider_input nb_f_'.$class.' '.$optional.'" maxlength="2" />
			<span>'.$data['value'].'</span>';
			break;
	}

	return $pre_code . $code . '</div>';
}

