<?php
// LC DASHBOARD REGISTRATION
// IMPORTANT: dashboard engine versioning must be declared in the $LCWPD_VERSION variable



// AJAX_SIDE REGISTRATION
// be sure to use always the last version 
add_action('admin_init', function() {
    if(!defined('DOING_AJAX')) {
        return false;    
    }
    $LCWPD_VERSION = '1.0.7';

    if(isset($GLOBALS['lc_wp_dash_ajax_registr']) && version_compare(
        $LCWPD_VERSION,
        $GLOBALS['lc_wp_dash_ajax_registr'], 
        '<='
    )) {
        return false;
    }
    
    $GLOBALS['lc_wp_dash_ajax_registr'] = $LCWPD_VERSION;
}, 1);


// init
add_action('admin_init', function() {
    $LCWPD_VERSION = '1.0.7';
    
    if(!defined('DOING_AJAX')) {
        return false;    
    }
    if($GLOBALS['lc_wp_dash_ajax_registr'] != $LCWPD_VERSION || isset($GLOBALS['lc_wp_dash_ajax_init'])) {
        return false;   
    }
    
    include_once( __DIR__ .'/products.php');
    include_once( __DIR__ .'/ajax.php');  
    
    $GLOBALS['lc_wp_dash_ajax_init'] = true;
}, 2);







// ADMIN-SIDE REGISTRATION
// be sure to use always the last version 
add_action('admin_menu', function() {
    $LCWPD_VERSION = '1.0.7';
    
    if(isset($GLOBALS['lc_wp_dash_registr']) && version_compare(
        $LCWPD_VERSION,
        $GLOBALS['lc_wp_dash_registr'],
        '<='
    )) {
        return false;
    }
    
    $GLOBALS['lc_wp_dash_registr'] = $LCWPD_VERSION;
}, 1);





// init
add_action('admin_menu', function() {
    $LCWPD_VERSION = '1.0.7';
    
    if($GLOBALS['lc_wp_dash_registr'] != $LCWPD_VERSION || isset($GLOBALS['lc_wp_dash_init'])) {
        return false;   
    }
    include_once( __DIR__ .'/products.php');
    include_once( __DIR__ .'/licenses.php');
    
    $arr = explode('/wp-content', str_replace('\\', '/', __DIR__));
    $baseurl = untrailingslashit(site_url()) .'/wp-content'. end($arr);
    
    $GLOBALS['lcwpd_baseurl'] = untrailingslashit($baseurl);
    lcwpd_menu();
    
    // updater init for each
    lcwpd_licenses::init_updater();
    
    $GLOBALS['lc_wp_dash_init'] = true;
}, 2);







// operations needing one-only perform
if(!function_exists('lcwpd_menu')) {
    
    // menu
    function lcwpd_menu() {
        add_submenu_page('index.php', 'LCweb Dashboard', 'LCweb Dashboard', 'install_plugins', 'lc_wp_dashboard', 'lc_wp_dashboard');           
    }
    function lc_wp_dashboard() {
        include_once( __DIR__ .'/licenses.php');  
        include_once( __DIR__ .'/dashboard.php');  
    }
    
    
    
    // scripts enqueuing
    function lcwpd_scripts() {
        global $current_screen;

        if($current_screen->base == 'dashboard_page_lc_wp_dashboard' || $current_screen->base == 'plugins') {
            wp_enqueue_style('lcwpd_admin', $GLOBALS['lcwpd_baseurl'] .'/assets/css.css', 100, $GLOBALS['lc_wp_dash_registr']);
        }
    }
    add_action('admin_enqueue_scripts', 'lcwpd_scripts', 99999);
    
    
    
    // intercept old updater link in plugins list and redirect to new dashboard
    function lcwpd_plugins_list_manipulate_old_updater() {
        global $current_screen;
        if($current_screen->base != 'plugins') {
            return false;    
        }
        ?>
        <script type="text/javascript">
        (function() { 
            "use strict";   
            
            document.querySelectorAll('.lcwpau_wizard_btn').forEach(function($btn) {
                $btn.setAttribute('href', "<?php echo admin_url() ?>index.php?page=lc_wp_dashboard");
                $btn.classList.remove('thickbox');
            });
        })();    
        </script>
        <?php
    }
    add_action('admin_footer', 'lcwpd_plugins_list_manipulate_old_updater');
    
    
    
    // dashboard redirect after plugin activation
    function lcwpd_pre_redirect_on_activation($plugin) {
        update_site_option('lcwpd_activation_redirect_flag', 1);
    }
    add_action('activated_plugin', 'lcwpd_pre_redirect_on_activation', 999);
    
    
    function lcwpd_redirect_on_activation() {
        $activity_flag_opt_name = 'lcwpd_activation_redirect_flag';
        $versions_opt_name = 'lcwpd_activation_redirect_helper';

        if(!get_site_option($activity_flag_opt_name) || !current_user_can('install_plugins') || strpos($_SERVER["REQUEST_URI"], '/plugins.php') === false) {
            return false;    
        }
        
        delete_site_option($activity_flag_opt_name);
        $stored_versions = get_site_option($versions_opt_name);

        $to_save = array();
        foreach($GLOBALS['lcwpd_products'] as $path => $prod_data) {
            if(!is_plugin_active($path)) {
                continue;
            }

            $plugin_data = get_plugin_data(WP_PLUGIN_DIR .'/'. $path);
            $to_save[ $prod_data['slug'] ] = $plugin_data['Version'];
        }

        if($stored_versions == $to_save) {
            return true;    
        }
        update_site_option($versions_opt_name, $to_save);
        
        foreach($to_save as $slug => $new_version) {
            if(empty($stored_versions) || !isset($stored_versions[$slug]) || (isset($stored_versions[$slug]) && $stored_versions[$slug] != $new_version)) {

                $url = admin_url() .'index.php?page=lc_wp_dashboard';
                
                if(!isset($stored_versions[$slug])) {
                    $url .= '&prod_welcome='. $slug;    
                }

                // updating the plugin - show changelog
                else if(!empty($stored_versions) && isset($stored_versions[$slug])) {
                    $url .= '&prod_updated&prod_cl='. $slug;            
                }

                wp_safe_redirect($url);
                break;
            }
        }
    }
    add_action('admin_init', 'lcwpd_redirect_on_activation');

}
