<?php
/* 
Plugin Name: Swift Box
Plugin URI: https://lcweb.it/swift-box-wordpress-plugin
Description: Display contents from different sources in an unique, responsive, environment. Create your own style and customize every single aspect of the box.
Author: Luca Montanari
Version: 2.4.4
Author URI: https://lcweb.it
*/  


/////////////////////////////////////////////
/////// MAIN DEFINES ////////////////////////
/////////////////////////////////////////////

// plugin path
$wp_plugin_dir = substr(plugin_dir_path(__FILE__), 0, -1);
define( 'NB_DIR', $wp_plugin_dir);

// plugin url
$wp_plugin_url = substr(plugin_dir_url(__FILE__), 0, -1);
define( 'NB_URL', $wp_plugin_url);


define('NB_VER', '2.4.4');
define('NB_JS_VER', '2.4.0');


// multilang key
define('NB_ML', 'nb_ml');



/////////////////////////////////////////////
/////// FORCING DEBUG ///////////////////////
/////////////////////////////////////////////

if(isset($_REQUEST['nb_debug'])) {
	ini_set('display_errors', 1);
	ini_set('display_startup_errors', 1);
	error_reporting(E_ALL);	
}



/////////////////////////////////////////////
/////// MULTILANGUAGE SUPPORT ///////////////
/////////////////////////////////////////////

function nb_multilanguage() {
	$param_array = explode('/', NB_DIR);
 	$folder_name = end($param_array);
	
	load_plugin_textdomain('nb_ml', false, $folder_name .'/languages'); 
}
add_action('plugins_loaded', 'nb_multilanguage', 1);



/////////////////////////////////////////////
/////// MAIN SCRIPT & CSS INCLUDES //////////
/////////////////////////////////////////////


// global script enqueuing
function nb_global_scripts() {
	wp_enqueue_script('jquery');

	$is_admin = is_admin();

	// admin
	if($is_admin) {  
        global $current_screen;
        if(!$current_screen) {
            return;     
        }
        
		wp_enqueue_style('nb_admin', NB_URL . '/css/admin.css', 999, NB_VER);
		
        // magnificPopup
        wp_enqueue_style('lcwp-magpopup', NB_URL .'/js/sb/js_assets/magnific-popup/magnific-popup-style.css');
        wp_enqueue_script('lcwp-magpopup', NB_URL .'/js/sb/js_assets/magnific-popup/magnific-popup.min.js', 70, '1.1.0', true);
        
        // LC tools
		wp_enqueue_style('lcwp-lc-select',      NB_URL .'/js/lc-select/themes/lcwp_prefixed.css');
        wp_enqueue_script('lc-select',          NB_URL .'/js/lc-select/lc_select.min.js', 100, '1.1.4', true);
        
        wp_enqueue_script('lc-switch-v2',       NB_URL.'/js/lc-switch/lc_switch.min.js', 200, '2.0.3', true);
        wp_enqueue_script('lc-range-n-num',     NB_URL .'/js/lc-range-n-num/lc_range_n_num.min.js', 200, '1.0.1', true);
        wp_enqueue_script('lc-wp-popup-message',NB_URL .'/js/lc-wp-popup-message/lc_wp_popup_message.min.js', 200, '1.0', true);
        
        
        // settings page scripts
        if($current_screen->base == 'swift-box_page_nb_settings') {
            $baseurl = NB_URL .'/js';
            wp_enqueue_style('nb_settings', NB_URL .'/settings/settings_style.css', 999, NB_VER);	
            
            wp_enqueue_script('lc-color-picker',    $baseurl .'/lc-color-picker/lc_color_picker.min.js', 200, '1.1.1', true);
            
            wp_enqueue_style('codemirror',          $baseurl .'/codemirror/codemirror.css');
            wp_enqueue_script('codemirror',         $baseurl .'/codemirror/codemirror.min.js', 200, '1.0', true);
            wp_enqueue_script('codemirror-lang-css',$baseurl .'/codemirror/languages/css.min.js', 201, '1.0', true);
        }
	}
	
	
	// frontend
	if(!$is_admin || isset($GLOBALS['lc_guten_scripts'])) {
		$in_footer = (get_option('nb_js_head') != '1') ? true : false;

		// core scripts
		wp_enqueue_style('nb-core',  NB_URL.'/js/sb/swift-box-layout.min.css', 900, NB_VER);
		wp_enqueue_script('nb-core', NB_URL.'/js/sb/swift-box.min.js', 100, NB_VER, $in_footer);
		
		// theme
		if(!get_option('nb_inline_css') || !get_option('nb_custom_style')) {
			
			$theme = (get_option('nb_custom_style')) ? 'wpdt' : get_option('nb_main_style', 'minimal');
			wp_enqueue_style('nb-theme', NB_URL.'/js/sb/themes/'. $theme .'.css', 900, NB_VER .'-'. get_option('nb_dynamic_scripts_id'));
		}

		
        if(class_exists('DiviExtension')) {
            wp_enqueue_style('nb-core-for-divi',  NB_URL.'/js/sb/swift-box-layout.min_for_divi.css', 905, NB_VER);
            wp_enqueue_style('nb-theme-for-divi', NB_URL.'/js/sb/themes/'. $theme .'_for_divi.css', 906, NB_VER .'-'. get_option('nb_dynamic_scripts_id'));	     
        }
        
        
        
		// Magnific Popup
		if(get_option('nb_lightbox', 1) || get_option('nb_exp_in_lb')) {
			wp_enqueue_style('nb-lightbox',  NB_URL.'/js/sb/js_assets/magnific-popup/magnific-popup-style.css', 900, NB_VER);
			wp_enqueue_script('nb-lightbox', NB_URL.'/js/sb/js_assets/magnific-popup/magnific-popup.min.js', 99, NB_VER, $in_footer);
		}
		
		// Touchswipe
		if(get_option('nb_touchswipe')) {
			wp_enqueue_script('nb-touchswipe', NB_URL.'/js/sb/js_assets/TouchSwipe/jquery.touchSwipe.min.js', 99, NB_VER, $in_footer);	
		}


		// frontend custom css inline - custom font sizes
		add_action('wp_head', 'nb_inline_css', 989);
	}
}
add_action('wp_enqueue_scripts', 'nb_global_scripts', 900);
add_action('admin_enqueue_scripts', 'nb_global_scripts');
add_action('lc_guten_scripts', 'nb_global_scripts');



// USE FRONTEND CSS INLINE
function nb_inline_css(){
	$typography_css 	= '';
	$title_font_family 	= get_option('nb_title_font_family');
	$txt_font_family 	= get_option('nb_txt_font_family');
	
	
	// font family 
	if(!empty($title_font_family)) {
		$typography_css .= '.lcnb_title {font-family: '. $title_font_family .';}';	
	}
	if(!empty($txt_font_family)) {
		$typography_css .= '.lcnb_txt, .lcnb_exp_txt > *:not(.lcnb_title) {font-family: '. $txt_font_family .';}';	
	}
	
	// initial mode - desktop
	if((int)get_option('nb_is_title_size', 16) != 16) {
		$typography_css .= 
			'.lcnb_title {font-size: '.get_option('nb_is_title_size', 16).'px; line-height: '. ((int)get_option('nb_is_title_size', 16) + 6) .'px;} ';
	}
	if((int)get_option('nb_is_txt_size', 14) != 14) {
		$typography_css .= 
			'.lcnb_txt {font-size: '.get_option('nb_is_txt_size', 14).'px; line-height: '. ((int)get_option('nb_is_txt_size', 14) + 6) .'px;} ';
	}
	
	// initial mode - mobile
	if((int)get_option('nb_ism_title_size', 14) != 14) {
		$typography_css .= 
			'@media screen and (max-width:960px) { 
				.lcnb_title {font-size: '.get_option('nb_ism_title_size', 14).'px; line-height: '. ((int)get_option('nb_ism_title_size', 14) + 6) .'px;}
			}';
	}
	if((int)get_option('nb_ism_txt_size', 12) != 12) {
		$typography_css .= 
			'@media screen and (max-width:960px) { 
				.lcnb_title {font-size: '.get_option('nb_ism_txt_size', 12).'px; line-height: '. ((int)get_option('nb_ism_txt_size', 12) + 6) .'px;}
			}';
	}
	
	// expanded mode - desktop
	if((int)get_option('nb_es_title_size', 21) != 21) {
		$typography_css .= 
			'.lcnb_exp_block .lcnb_title {font-size: '.get_option('nb_es_title_size', 21).'px; line-height: '. ((int)get_option('nb_es_title_size', 21) + 8) .'px;} ';
	}
	if((int)get_option('nb_es_txt_size', 14) != 14) {
		$typography_css .= 
			'.lcnb_exp_txt > *:not(.lcnb_title) {font-size: '.get_option('nb_es_txt_size', 14).'px; line-height: '. ((int)get_option('nb_es_txt_size', 14) + 7) .'px;} ';
	}
	
	// expanded mode - mobile
	if((int)get_option('nb_esm_title_size', 18) != 18) {
		$typography_css .= 
			'@media screen and (max-width:960px) { 
				.lcnb_exp_block .lcnb_title {font-size: '.get_option('nb_esm_title_size', 18).'px; line-height: '. ((int)get_option('nb_esm_title_size', 18) + 8) .'px;}
			}';
	}
	if((int)get_option('nb_esm_txt_size', 12) != 12) {
		$typography_css .= 
			'@media screen and (max-width:960px) { 
				.lcnb_exp_txt > *:not(.lcnb_title) {font-size: '.get_option('nb_esm_txt_size', 12).'px; line-height: '. ((int)get_option('nb_esm_txt_size', 12) + 7) .'px;}
			}';
	}
	
	
	
	// bad server - use custom theme inline
	if((get_option('nb_inline_css') || get_option('nb_force_inline_css')) && get_option('nb_custom_style')) {
		if(get_option('nb_inline_css') || get_option('nb_force_inline_css')) {
			if(isset($GLOBALS['nb_printed_inline_css'])) { // avoid double enqueuing with Gutenberg
				return false;	
			}
			$GLOBALS['nb_printed_inline_css'] = true;
			
			echo '<style type="text/css">';
			include_once(NB_DIR . '/custom_theme_css.php');
			echo '</style>';		
		}
	}
	
	
	// custom CSS
	$custom_css = $typography_css . get_option('nb_custom_css');
	if(!empty($custom_css)) {
        echo '<style type="text/css">'.$custom_css.'</style>';
    }
}





/////////////////////////////////////////////
/////// MAIN INCLUDES ///////////////////////
/////////////////////////////////////////////

// admin menu and cpt and taxonomy
include_once(NB_DIR . '/admin_menu.php');

// quick news metaboxes
include_once(NB_DIR . '/metaboxes.php');

// Head JS vars
include_once(NB_DIR . '/head_js.php');

// shortcode
include_once(NB_DIR . '/shortcode.php');

// tinymce integration
include_once(NB_DIR . '/tinymce_implementation.php');

// ajax
include_once(NB_DIR . '/ajax.php');

// date placeholders helper
include_once(NB_DIR . '/date_format_helper.php');

// box preview
include_once(NB_DIR . '/nb_preview.php');



// gutenberg integration
// gutenberg integration - not for WP 5.8 widgets.. for now
if($_SERVER["REQUEST_URI"] != '/wp-admin/widgets.php') {
    include_once(NB_DIR . '/builders_integration/gutenberg.php');
}

// visual composer integration
include_once(NB_DIR . '/builders_integration/visual_composer.php');

// cornerstone integration
include_once(NB_DIR . '/builders_integration/cornerstone.php');

// elementor integration
include_once(NB_DIR . '/builders_integration/elementor.php');

// Divi integration
include_once(NB_DIR . '/builders_integration/divi.php');







////////////
// LC WP DASHBOARD

function nb_lcwpb_updater_data($data) {
    $data['sb'] = array(
        'callback' => 'nb_on_activation',
        'no_files_del' => false,
    );
    return $data;
}
add_filter('lcwpb_updater_data', 'nb_lcwpb_updater_data');

include_once(NB_DIR .'/lc_wp_dashboard/register.php');


////////////







//////////////////////////////////////////////////
// ACTIONS ON PLUGIN ACTIVATION
function nb_on_activation() {
	include_once(NB_DIR . '/functions.php');
	
	// if enabled - create custom theme
	if(get_option('nb_custom_style')) {
		if(!nb_create_custom_theme()) {
			if(!get_option('nb_inline_css')) {
                update_option('nb_inline_css', 1);
            }
		}
		else {
            delete_option('nb_inline_css');
        }
	}
}
register_activation_hook(__FILE__, 'nb_on_activation');



